@@ -33,7 +33,7 @@ our %EXPORT_TAGS = (
     width_one	=> [ qw{ raw_width width } ],
 );
 
-our $VERSION = '0.085_01';
+our $VERSION = '0.085_02';
 
 sub is_ppi_regexp_element {
     my ( $elem ) = @_;
@@ -82,9 +82,11 @@ sub __merge_perl_requirements {	## no critic (RequireArgUnpacking)
 	if ( @work ) {
 	    $rem = $work[0][0];
 	    shift @work while @work && ! $work[0][1];
-	} else {
-	    $rem = INFINITY;
 	}
+	defined $intro
+	    or $intro = MINIMUM_PERL;
+	defined $rem
+	    or $rem = INFINITY;
 	$intro != $rem
 	    and push @rslt, {
 		introduced	=> $intro,
